YARP 2.3.70.2 (2017-12-11)                                          {#v2_3_70_2}
==========================

[TOC]

YARP 2.3.70.2 Release Notes
===========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v2.3.70.2%22).


Important Changes
-----------------

### Libraries

#### `YARP_OS`

* Unification of code in `DGramTwoWayStream` for the allocation of write
  and read buffers (#899).
* Added extra checks in the port names in `Network:metaConnect()`, with
  dedicated error messages.

#### `YARP_math`

* The `RandScalar` methods are now using C++11 `mersenne_twister_engine` instead
  of a custom engine.

### Carriers

* `portmonitor`, `rossrv`, `tcpros`, and `xmlrpc` carriers can now be enabled
  when `SKIP_ACE` is `ON`.

### Build System

* Added `YARP_DISABLE_OSX_BUNDLES` option to disable macOS bundles.

* Added `YARP_DISABLE_FAILING_TESTS` option to disable tests known for randomly
  failing due to race conditions.


Bug Fixes
---------

* Fixed several warnings reported by Clang static analyzer.
* Fixed several defects reported by Coverity.

### Libraries

#### `YARP_OS`

* Fixed truncation of double in `Property::fromString()`.
* Fixed append to wrong string in `BufferedConnectionWriter.h`.
* Fixed `yarp::os::ConstString::getline` for MSVC (#1357).
* Reverted `flush()` added in YARP v2.3.71.1 at the end of
  `AbstractCarrier::writeYarpInt()`.

#### `YARP_dev`

* Fixed RPC calls when connecting to right image port (split mode on)

### Tools

* Added the fallback port in `yarpserver` also if `yarp`
  is compiled without ACE, since we support mcast without
  ACE since `v2.3.70`.
* Fixed `yarpdev --list` for Windows.


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.70.1..v2.3.70.2`):

```
   144	Damiano Enerli <damiano.enerli@iit.it>
    60	Nicolò Genesio <nicolo.genesio@iit.it>
    40	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     9	Alberto Cardellino <alberto.cardellino@iit.it>
     3	Silvio Traversaro <silvio.traversaro@iit.it>
     1	Marco Monforte <marco.monforte@iit.it>
```
